@@ -574,20 +574,27 @@ meta_ui_get_default_window_icon (MetaUI *ui)
 
   if (default_icon == NULL)
     {
-      GdkPixbuf *base;
+      GtkIconTheme *theme;
+      gboolean icon_exists;
 
-      base = gdk_pixbuf_new_from_inline (-1, default_icon_data,
-                                         FALSE,
-                                         NULL);
+      theme = gtk_icon_theme_get_default ();
 
-      g_assert (base);
+      icon_exists = gtk_icon_theme_has_icon (theme, META_DEFAULT_ICON_NAME);
 
-      default_icon = gdk_pixbuf_scale_simple (base,
-                                              META_ICON_WIDTH,
-                                              META_ICON_HEIGHT,
-                                              GDK_INTERP_BILINEAR);
+      if (icon_exists)
+          default_icon = gtk_icon_theme_load_icon (theme,
+                                                   META_DEFAULT_ICON_NAME,
+                                                   META_ICON_WIDTH,
+                                                   0,
+                                                   NULL);
+      else
+          default_icon = gtk_icon_theme_load_icon (theme,
+                                                   "gtk-missing-image",
+                                                   META_ICON_WIDTH,
+                                                   0,
+                                                   NULL);
 
-      g_object_unref (G_OBJECT (base));
+      g_assert (default_icon);
     }
 
   g_object_ref (G_OBJECT (default_icon));
@@ -602,20 +609,27 @@ meta_ui_get_default_mini_icon (MetaUI *ui)
 
   if (default_icon == NULL)
     {
-      GdkPixbuf *base;
+      GtkIconTheme *theme;
+      gboolean icon_exists;
 
-      base = gdk_pixbuf_new_from_inline (-1, default_icon_data,
-                                         FALSE,
-                                         NULL);
+      theme = gtk_icon_theme_get_default ();
 
-      g_assert (base);
+      icon_exists = gtk_icon_theme_has_icon (theme, META_DEFAULT_ICON_NAME);
 
-      default_icon = gdk_pixbuf_scale_simple (base,
-                                              META_MINI_ICON_WIDTH,
-                                              META_MINI_ICON_HEIGHT,
-                                              GDK_INTERP_BILINEAR);
+      if (icon_exists)
+          default_icon = gtk_icon_theme_load_icon (theme,
+                                                   META_DEFAULT_ICON_NAME,
+                                                   META_MINI_ICON_WIDTH,
+                                                   0,
+                                                   NULL);
+      else
+          default_icon = gtk_icon_theme_load_icon (theme,
+                                                   "gtk-missing-image",
+                                                   META_MINI_ICON_WIDTH,
+                                                   0,
+                                                   NULL);
 
-      g_object_unref (G_OBJECT (base));
+      g_assert (default_icon);
     }
 
   g_object_ref (G_OBJECT (default_icon));
@@ -983,16 +997,3 @@ meta_ui_get_pixbuf_from_pixmap (Pixmap   pmap)
 
   return pixbuf;
 }
-  
-void
-meta_ui_get_fallback_icons (GdkPixbuf **fallback_icon_p,
-                            GdkPixbuf **fallback_mini_icon_p)
-{
-  MetaTheme *theme = meta_theme_get_current ();
-
-  if (fallback_icon_p)
-    *fallback_icon_p = theme->fallback_icon;
-
-  if (fallback_mini_icon_p)
-    *fallback_mini_icon_p = theme->fallback_mini_icon;  
-}
